@@ -8,7 +8,7 @@ use warnings NONFATAL => 'all';
 use AnyEvent;
 
 # ABSTRACT: Request buffer role for asynchronous ftp client
-our $VERSION = '0.04_01'; # VERSION
+our $VERSION = '0.01'; # VERSION
 
 
 has request_buffer => (
@@ -139,7 +139,7 @@ AnyEvent::FTP::Client::Role::RequestBuffer - Request buffer role for asynchronou
 
 =head1 VERSION
 
-version 0.04_01
+version 0.01
 
 =head1 DESCRIPTION
 
@@ -147,13 +147,7 @@ Used internally by L<AnyEvent::FTP::Client>.
 
 =head1 AUTHOR
 
-author: Graham Ollis <plicease@cpan.org>
-
-contributors:
-
-Ryo Okamoto
-
-Shlomi Fish
+Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
