@@ -7,7 +7,7 @@ use Moo;
 use warnings NONFATAL => 'all';
 
 # ABSTRACT: base class for AnyEvent::FTP::Client::Site::* classes
-our $VERSION = '0.04_01'; # VERSION
+our $VERSION = '0.01'; # VERSION
 
 sub BUILDARGS
 {
@@ -31,17 +31,11 @@ AnyEvent::FTP::Client::Site::Base - base class for AnyEvent::FTP::Client::Site::
 
 =head1 VERSION
 
-version 0.04_01
+version 0.01
 
 =head1 AUTHOR
 
-author: Graham Ollis <plicease@cpan.org>
-
-contributors:
-
-Ryo Okamoto
-
-Shlomi Fish
+Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
