@@ -9,7 +9,7 @@ use warnings NONFATAL => 'all';
 extends 'AnyEvent::FTP::Client::Site::Base';
 
 # ABSTRACT: Site specific commands for Net::FTPServer
-our $VERSION = '0.04_01'; # VERSION
+our $VERSION = '0.01'; # VERSION
 
 
 # TODO add a test for this
@@ -30,7 +30,7 @@ AnyEvent::FTP::Client::Site::NetFtpServer - Site specific commands for Net::FTPS
 
 =head1 VERSION
 
-version 0.04_01
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -83,13 +83,7 @@ patches that include tests are welcome.
 
 =head1 AUTHOR
 
-author: Graham Ollis <plicease@cpan.org>
-
-contributors:
-
-Ryo Okamoto
-
-Shlomi Fish
+Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
