@@ -10,7 +10,7 @@ use AnyEvent::Socket qw( tcp_connect );
 extends 'AnyEvent::FTP::Client::Transfer';
 
 # ABSTRACT: Passive transfer class for asynchronous ftp client
-our $VERSION = '0.04_01'; # VERSION
+our $VERSION = '0.01'; # VERSION
 
 sub BUILD
 {
@@ -88,17 +88,11 @@ AnyEvent::FTP::Client::Transfer::Passive - Passive transfer class for asynchrono
 
 =head1 VERSION
 
-version 0.04_01
+version 0.01
 
 =head1 AUTHOR
 
-author: Graham Ollis <plicease@cpan.org>
-
-contributors:
-
-Ryo Okamoto
-
-Shlomi Fish
+Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
