@@ -8,7 +8,7 @@ use overload
   fallback => 1;
 
 # ABSTRACT: Response class for asynchronous ftp client
-our $VERSION = '0.04_01'; # VERSION
+our $VERSION = '0.01'; # VERSION
 
 
 sub new
@@ -51,7 +51,7 @@ AnyEvent::FTP::Response - Response class for asynchronous ftp client
 
 =head1 VERSION
 
-version 0.04_01
+version 0.01
 
 =head1 DESCRIPTION
 
@@ -123,13 +123,7 @@ is the same as
 
 =head1 AUTHOR
 
-author: Graham Ollis <plicease@cpan.org>
-
-contributors:
-
-Ryo Okamoto
-
-Shlomi Fish
+Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
