@@ -11,7 +11,7 @@ use AnyEvent::FTP::Server::Connection;
 use Socket qw( unpack_sockaddr_in inet_ntoa );
 
 # ABSTRACT: Simple asynchronous ftp server
-our $VERSION = '0.04_01'; # VERSION
+our $VERSION = '0.01'; # VERSION
 
 
 $AnyEvent::FTP::Server::VERSION //= 'dev';
@@ -205,7 +205,7 @@ AnyEvent::FTP::Server - Simple asynchronous ftp server
 
 =head1 VERSION
 
-version 0.04_01
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -281,13 +281,7 @@ L<Net::FTPServer>
 
 =head1 AUTHOR
 
-author: Graham Ollis <plicease@cpan.org>
-
-contributors:
-
-Ryo Okamoto
-
-Shlomi Fish
+Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
