@@ -7,7 +7,7 @@ use Moo::Role;
 use warnings NONFATAL => 'all';
 
 # ABSTRACT: Help role for FTP server
-our $VERSION = '0.04_01'; # VERSION
+our $VERSION = '0.01'; # VERSION
 
 
 my %cmds;
@@ -74,7 +74,7 @@ AnyEvent::FTP::Server::Role::Help - Help role for FTP server
 
 =head1 VERSION
 
-version 0.04_01
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -133,13 +133,7 @@ the C<HELP> command for you.
 
 =head1 AUTHOR
 
-author: Graham Ollis <plicease@cpan.org>
-
-contributors:
-
-Ryo Okamoto
-
-Shlomi Fish
+Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
