@@ -7,7 +7,7 @@ use Moo;
 use warnings NONFATAL => 'all';
 
 # ABSTRACT: Server response encoder that encodes responses so they cannot be confused
-our $VERSION = '0.04_01'; # VERSION
+our $VERSION = '0.01'; # VERSION
 
 
 with 'AnyEvent::FTP::Server::Role::ResponseEncoder';
@@ -51,7 +51,7 @@ AnyEvent::FTP::Server::UnambiguousResponseEncoder - Server response encoder that
 
 =head1 VERSION
 
-version 0.04_01
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -74,13 +74,7 @@ L<AnyEvent::FTP::Response> object, or a code message pair.
 
 =head1 AUTHOR
 
-author: Graham Ollis <plicease@cpan.org>
-
-contributors:
-
-Ryo Okamoto
-
-Shlomi Fish
+Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
