@@ -13,7 +13,7 @@ use Path::Class qw( tempdir );
 extends 'AnyEvent::FTP::Server';
 
 # ABSTRACT: Test (non-blocking) ftp clients against a real FTP server
-our $VERSION = '0.04_01'; # VERSION
+our $VERSION = '0.01'; # VERSION
 
 
 has test_uri => (
@@ -384,8 +384,6 @@ sub _display_content
   my $tb = shift;
   state $temp;
   state $counter = 0;
-  my $method = 'diag';
-  $method = 'note' if $tb->todo;
   
   unless(defined $temp)
   {
@@ -397,17 +395,17 @@ sub _display_content
   
   if(-T $file)
   {
-    $tb->$method("  $_") for split /\n/, $_[0];
+    $tb->diag("  $_") for split /\n/, $_[0];
   }
   else
   {
     if(eval { require Data::HexDump })
     {
-      $tb->$method("  $_") for grep !/^$/, split /\n/, Data::HexDump::HexDump($_[0]);
+      $tb->diag("  $_") for grep !/^$/, split /\n/, Data::HexDump::HexDump($_[0]);
     }
     else
     {
-      $tb->$method("  binary content");
+      $tb->diag("  binary content");
     }
   }
   
@@ -438,7 +436,7 @@ sub global_timeout_ok (;$$)
 {
   my($timeout, $message) = @_;
   
-  $timeout //= 120;
+  $timeout //= 30;
   $message //= "global timeout of $timeout seconds";
   
   my $tb = Test::Builder::Module->builder;
@@ -481,7 +479,7 @@ Test::AnyEventFTPServer - Test (non-blocking) ftp clients against a real FTP ser
 
 =head1 VERSION
 
-version 0.04_01
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -627,17 +625,11 @@ Set a global timeout on the entire test script.  If the timeout
 is exceeded the test will exit.  Handy if you have test automation
 and your test automation doesn't handle hung tests.
 
-The default timeout is 120 seconds.
+The default timeout is 30 seconds.
 
 =head1 AUTHOR
 
-author: Graham Ollis <plicease@cpan.org>
-
-contributors:
-
-Ryo Okamoto
-
-Shlomi Fish
+Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
